@@ -3,6 +3,8 @@ import sys
 import click
 
 from mhd_model.commands.create.announcement import create_announcement_file_task
+from mhd_model.commands.create.neo4j_input import create_neo4j_input_file_task
+from mhd_model.commands.create.sdrf import create_sdrf_file_task
 
 
 @click.group(name="create", context_settings={"help_option_names": ["-h", "--help"]})
@@ -12,6 +14,9 @@ def create_group():
 
 
 create_group.add_command(create_announcement_file_task)
+create_group.add_command(create_sdrf_file_task)
+create_group.add_command(create_neo4j_input_file_task)
+
 
 if __name__ == "__main__":
     if len(sys.argv) == 1:
