@@ -3,6 +3,7 @@ import sys
 import click
 
 from mhd_model.commands.validate.announcement import validate_announcement_file_task
+from mhd_model.commands.validate.mhd_file import validate_mhd_file_task
 
 
 @click.group(name="validate", context_settings={"help_option_names": ["-h", "--help"]})
@@ -12,6 +13,8 @@ def validate_group():
 
 
 validate_group.add_command(validate_announcement_file_task)
+validate_group.add_command(validate_mhd_file_task)
+
 
 if __name__ == "__main__":
     if len(sys.argv) == 1:
