@@ -475,7 +475,7 @@ MHD_BASE_VALIDATION_V0_1.mhd_nodes = [
             ),
             RelationshipValidation(
                 source="parameter-definition",
-                relationship_name="defined-in",
+                relationship_name="used-in",
                 reverse_relationship_name="has-parameter-definition",
                 target="protocol",
                 min=0,
@@ -644,7 +644,7 @@ MHD_BASE_VALIDATION_V0_1.mhd_nodes = [
             NodePropertyValidation(
                 node_type="protocol",
                 node_property_name="description",
-                contraints=PropertyConstraint(required=True),
+                contraints=PropertyConstraint(required=False),
             ),
         ],
         relationships=[
@@ -667,7 +667,7 @@ MHD_BASE_VALIDATION_V0_1.mhd_nodes = [
             RelationshipValidation(
                 source="protocol",
                 relationship_name="has-parameter-definition",
-                reverse_relationship_name="defined-in",
+                reverse_relationship_name="used-in",
                 target="parameter-definition",
                 min=0,
                 min_for_each_source=0,
@@ -1457,9 +1457,9 @@ MHD_BASE_VALIDATION_V0_1.cv_nodes = [
                 condition=[
                     FilterCondition(
                         name="File Format",
-                        relationship_name="[embedded].compression_format_ref",
+                        relationship_name="[embedded].compression_format_refs",
                         start_node_type=None,
-                        expression="compression_format_ref",
+                        expression="compression_format_refs",
                     )
                 ],
             ),
@@ -1850,7 +1850,7 @@ MHD_BASE_VALIDATION_V0_1.cv_nodes = [
                         name="Mass spectrometry protocol",
                         relationship_name="[embedded].parameter_type_ref",
                         start_node_type="parameter-definition",
-                        expression="[defined-in].protocol_type_ref.accession",
+                        expression="[used-in].protocol_type_ref.accession",
                         expression_value="CHMO:0000470",
                     ),
                 ],
