@@ -469,7 +469,7 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
             ),
             RelationshipValidation(
                 source="parameter-definition",
-                relationship_name="defined-in",
+                relationship_name="used-in",
                 reverse_relationship_name="has-parameter-definition",
                 target="protocol",
                 min=0,
@@ -633,7 +633,7 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
             NodePropertyValidation(
                 node_type="protocol",
                 node_property_name="description",
-                contraints=PropertyConstraint(required=True),
+                contraints=PropertyConstraint(required=False),
             ),
         ],
         relationships=[
@@ -656,7 +656,7 @@ MHD_LEGACY_PROFILE_V0_1.mhd_nodes = [
             RelationshipValidation(
                 source="protocol",
                 relationship_name="has-parameter-definition",
-                reverse_relationship_name="defined-in",
+                reverse_relationship_name="used-in",
                 target="parameter-definition",
                 min=0,
                 min_for_each_source=0,
@@ -1489,9 +1489,9 @@ MHD_LEGACY_PROFILE_V0_1.cv_nodes = [
                 condition=[
                     FilterCondition(
                         name="File Format",
-                        relationship_name="[embedded].compression_format_ref",
+                        relationship_name="[embedded].compression_format_refs",
                         start_node_type=None,
-                        expression="compression_format_ref",
+                        expression="compression_format_refs",
                     )
                 ],
             ),
